# Security Policy

## Reporting a Vulnerability

Please report security vulnerabilities privately via
[GitHub Security Advisories](https://github.com/nbx-liz/LizyML-Widget/security/advisories/new).

Do **not** open a public issue for security vulnerabilities.

## Supported Versions

| Version | Supported |
|---------|-----------|
| Latest  | Yes       |
| < Latest | No       |

## Response Timeline

- **Acknowledgement**: Within 3 business days
- **Assessment**: Within 7 business days
- **Fix release**: As soon as practical after assessment
